@@ -1,7 +1,7 @@
 /*
  * Server start/stop routines for the CUPS scheduler.
  *
- * Copyright 2007-2017 by Apple Inc.
+ * Copyright 2007-2018 by Apple Inc.
  * Copyright 1997-2006 by Easy Software Products, all rights reserved.
  *
  * These coded instructions, statements, and computer programs are the
@@ -37,18 +37,30 @@ static int		started = 0;	/* Did we start the server already? */
 void
 cupsdStartServer(void)
 {
- /*
-  * Start color management (as needed)...
-  */
-
-  cupsdStartColor();
-
  /*
   * Create the default security profile...
   */
 
   DefaultProfile = cupsdCreateProfile(0, 1);
 
+#ifdef HAVE_SANDBOX_H
+  if (!DefaultProfile && UseSandboxing && Sandboxing != CUPSD_SANDBOXING_OFF)
+  {
+   /*
+    * Failure to create the sandbox profile means something really bad has
+    * happened and we need to shutdown immediately.
+    */
+
+    return;
+  }
+#endif /* HAVE_SANDBOX_H */
+
+ /*
+  * Start color management (as needed)...
+  */
+
+  cupsdStartColor();
+
  /*
   * Startup all the networking stuff...
   */
