@@ -3,7 +3,7 @@
  * commands such as IPP and Bonjour conformance tests.  This tool is
  * inspired by the UNIX "find" command, thus its name.
  *
- * Copyright 2008-2015 by Apple Inc.
+ * Copyright 2008-2018 by Apple Inc.
  *
  * These coded instructions, statements, and computer programs are the
  * property of Apple Inc. and are protected by Federal copyright
@@ -20,12 +20,12 @@
 
 #define _CUPS_NO_DEPRECATED
 #include <cups/cups-private.h>
-#ifdef WIN32
+#ifdef _WIN32
 #  include <process.h>
 #  include <sys/timeb.h>
 #else
 #  include <sys/wait.h>
-#endif /* WIN32 */
+#endif /* _WIN32 */
 #include <regex.h>
 #ifdef HAVE_DNSSD
 #  include <dns_sd.h>
@@ -39,9 +39,9 @@
 #  define kDNSServiceMaxDomainName AVAHI_DOMAIN_NAME_MAX
 #endif /* HAVE_DNSSD */
 
-#ifndef WIN32
+#ifndef _WIN32
 extern char **environ;			/* Process environment variables */
-#endif /* !WIN32 */
+#endif /* !_WIN32 */
 
 
 /*
@@ -156,7 +156,7 @@ static void DNSSD_API	browse_callback(DNSServiceRef sdRef,
 				        const char *serviceName,
 				        const char *regtype,
 				        const char *replyDomain, void *context)
-					__attribute__((nonnull(1,5,6,7,8)));
+					_CUPS_NONNULL((1,5,6,7,8));
 static void DNSSD_API	browse_local_callback(DNSServiceRef sdRef,
 					      DNSServiceFlags flags,
 					      uint32_t interfaceIndex,
@@ -165,7 +165,7 @@ static void DNSSD_API	browse_local_callback(DNSServiceRef sdRef,
 					      const char *regtype,
 					      const char *replyDomain,
 					      void *context)
-					      __attribute__((nonnull(1,5,6,7,8)));
+					      _CUPS_NONNULL((1,5,6,7,8));
 #elif defined(HAVE_AVAHI)
 static void		browse_callback(AvahiServiceBrowser *browser,
 					AvahiIfIndex interface,
@@ -191,7 +191,7 @@ static ippfind_srv_t	*get_service(cups_array_t *services,
 				     const char *serviceName,
 				     const char *regtype,
 				     const char *replyDomain)
-				     __attribute__((nonnull(1,2,3,4)));
+				     _CUPS_NONNULL((1,2,3,4));
 static double		get_time(void);
 static int		list_service(ippfind_srv_t *service);
 static ippfind_expr_t	*new_expr(ippfind_op_t op, int invert,
@@ -207,7 +207,7 @@ static void DNSSD_API	resolve_callback(DNSServiceRef sdRef,
 				         uint16_t txtLen,
 				         const unsigned char *txtRecord,
 				         void *context)
-				         __attribute__((nonnull(1,5,6,9, 10)));
+				         _CUPS_NONNULL((1,5,6,9, 10));
 #elif defined(HAVE_AVAHI)
 static int		poll_callback(struct pollfd *pollfds,
 			              unsigned int num_pollfds, int timeout,
@@ -227,8 +227,8 @@ static void		resolve_callback(AvahiServiceResolver *res,
 					 void *context);
 #endif /* HAVE_DNSSD */
 static void		set_service_uri(ippfind_srv_t *service);
-static void		show_usage(void) __attribute__((noreturn));
-static void		show_version(void) __attribute__((noreturn));
+static void		show_usage(void) _CUPS_NORETURN;
+static void		show_version(void) _CUPS_NORETURN;
 
 
 /*
@@ -1766,10 +1766,10 @@ dnssd_error_string(int error)		/* I - Error number */
     case kDNSServiceErr_PollingMode :
         return ("Service polling mode error.");
 
-#ifndef WIN32
+#ifndef _WIN32
     case kDNSServiceErr_Timeout :
         return ("Service timeout.");
-#endif /* !WIN32 */
+#endif /* !_WIN32 */
   }
 
 #  elif defined(HAVE_AVAHI)
@@ -1920,10 +1920,10 @@ exec_program(ippfind_srv_t *service,	/* I - Service */
   int		i,			/* Looping var */
 		myenvc,			/* Number of environment variables */
 		status;			/* Exit status of program */
-#ifndef WIN32
+#ifndef _WIN32
   char		program[1024];		/* Program to execute */
   int		pid;			/* Process ID */
-#endif /* !WIN32 */
+#endif /* !_WIN32 */
 
 
  /*
@@ -2058,7 +2058,7 @@ exec_program(ippfind_srv_t *service,	/* I - Service */
       myargv[i] = strdup(args[i]);
   }
 
-#ifdef WIN32
+#ifdef _WIN32
   if (getenv("IPPFIND_DEBUG"))
   {
     printf("\nProgram:\n    %s\n", args[0]);
@@ -2121,7 +2121,7 @@ exec_program(ippfind_srv_t *service,	/* I - Service */
     while (wait(&status) != pid)
       ;
   }
-#endif /* WIN32 */
+#endif /* _WIN32 */
 
  /*
   * Free memory...
@@ -2139,14 +2139,14 @@ exec_program(ippfind_srv_t *service,	/* I - Service */
 
   if (getenv("IPPFIND_DEBUG"))
   {
-#ifdef WIN32
+#ifdef _WIN32
     printf("Exit Status: %d\n", status);
 #else
     if (WIFEXITED(status))
       printf("Exit Status: %d\n", WEXITSTATUS(status));
     else
       printf("Terminating Signal: %d\n", WTERMSIG(status));
-#endif /* WIN32 */
+#endif /* _WIN32 */
   }
 
   return (status == 0);
@@ -2220,7 +2220,7 @@ get_service(cups_array_t *services,	/* I - Service array */
 static double
 get_time(void)
 {
-#ifdef WIN32
+#ifdef _WIN32
   struct _timeb curtime;		/* Current Windows time */
 
   _ftime(&curtime);
@@ -2234,7 +2234,7 @@ get_time(void)
     return (0.0);
   else
     return (curtime.tv_sec + 0.000001 * curtime.tv_usec);
-#endif /* WIN32 */
+#endif /* _WIN32 */
 }
 
 
